#ifndef CHEAPR_TYPES_H
#define CHEAPR_TYPES_H


namespace cheapr {
namespace internal {
// Custom internal R type
using r_type = uint8_t;
}
}

#endif
